/***************************************************************************
 *   Copyright (C) 2006 by M.Fedotov   *
 *   mo_fedotov@mail.ru   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KANYREMOTE_H_
#define _KANYREMOTE_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kmainwindow.h>
#include <ksystemtray.h>

#define EXIT_OK     0
#define EXIT_EXACT  -3
#define EXIT_NOK    -1
#define EXIT_DISCON 2
#define EXIT_ABORT  3

#define INET_SOCKET   	"socket:"
#define BT_SOCKET   	"bluetooth:"
#define TOFILE   	"/tmp/kanyremote.cmd.results"

#define SERVER_NO       0
#define SERVER_TCP      1
#define SERVER_BT       2

#define STATE_NOTINITED     	0
#define STATE_DEFSTYLE	    	1	
#define STATE_SR_BIND	    	4	
#define STATE_SR_READ  	    	6
	


/**
 * @short Application Main Window
 * @author M.Fedotov <mo_fedotov@mail.ru>
 * @version 0.1
 */

typedef struct TC
{
    QString id;
    int     type;
    int     ticks;
    float   tmout;
    int     times;
    int     maxTimes;
    QString cmd;
    QString lastValue;
    struct TC  *next;
} timerCmd;

class KAnyRemoteTrayIcon: public KSystemTray
{
	void mousePressEvent(QMouseEvent *e);

    public:
	KPopupMenu* contextMenu() const { return KSystemTray::contextMenu(); }
	KActionCollection* actionCollection() { return KSystemTray::actionCollection(); }

	KAnyRemoteTrayIcon(QWidget *parent = 0, const char *name = 0): 
			KSystemTray(parent, name) {}
};

class KAnyRemote : public KMainWindow
{
    Q_OBJECT

public:
	QString 		cfgFileName;
	QString 		autoConnect;

	KAnyRemoteTrayIcon 	*theTrayIcon;
 	QTimer 			*theFlashOff;
	int 			theResetCount;
	int 	    	    	state;

    /**
     * Default Constructor
     */
    KAnyRemote();

    KAnyRemote(bool a, bool b, int c, QString d, QString f);

    /**
     * Default Destructor
     */
    virtual ~KAnyRemote();

	void resetCfg(bool printConf);
	
	void Connect();
	void SetCfgFile(QString &theFile);

private slots:
	void gotMessage(const QString &theButton);
	void resetCfgFromGui();
	void doQuit();
	void flashOff();
	void checkBluetooth();
	void checkData();
	void checkAlarms();
	void autoRepeat();
	void getCallerID();
	void slotConfigure();
	void slotConnect();
    void handleTimerCmd();
    void showAbout();


private:
	void init(void);
	void loadFromConfig(void);
	void saveToConfig(void);
	void setPixmapsAndTooltips(int mode, QString t = QString::null);
    	void handleExitAndDisc(int ret);
	QPixmap* getPixmapByName(QString name, int size);

	int  menuItemConnectID;
	KHelpMenu* About;
};

#endif // _KANYREMOTE_H_
